try:
  from Products.LinguaPlone.public import *
except ImportError:
  # No multilingual support
  from Products.Archetypes.public import *

from Products.ATContentTypes.content.base import ATCTContent
from Products.Archetypes.Marshall import RFC822Marshaller
from Products.CMFCore import permissions

from Products.DataGridField import *

from config import PROJECTNAME


"""
SimpleCartItem based on 
PayPal items for building a shopping cart store (or can be used single item).
http://www.zope.org/Members/bowerymarc
and PloneMall
"""

schema = BaseSchema.copy() +  Schema((

    FloatField( 'price',
                required=1,
                widget=DecimalWidget(label='Price',
                                     description='Price for your item -- do NOT include currency symbols!',
                                     label_msgid='label_price',
                                     description_msgid='help_price',
                                     i18n_domain='simplecartitem',
                                     ),
                validator='isDecimal',
  
             ),
    TextField( 'description',
                searchable=1,
                widget=TextAreaWidget(label='Basic Description',
                                      description='Short description of the item; it will show up in listing views.',
                                      allow_file_upload = False,
                                      label_msgid='label_description',
                                      description_msgid='help_description',
                                      i18n_domain='simplecartitem',
                                      ),
               
                isMetadata=1,            
               
                accessor='Description', 
                default_output_type='text/plain',
                allowable_content_types=('text/plain',),
              ),



    TextField( 'short_description',
                searchable=1,
                widget=RichWidget(label='Extended Description',
                                  description='Detailed description of the item',
                                  allow_file_upload = False,
                                  label_msgid='label_short_description',
                                  description_msgid='help_short_description',
                                  i18n_domain='simplecartitem',
                                  ),
                required=1,
                default_output_type='text/html',
                allowable_content_types=('text/html',
                         'text/plain',
                         'text/structured',
                         ),
                ),
    StringField('options_description',
              searchable=1,
              widget= StringWidget(label='Options Label',
                                   description="""For instance, "Size" or "Colors".""",
                                   label_msgid='label_options_description',
                                   description_msgid='help_options_description',
                                   i18n_domain='simplecartitem',
                                   ),
              required=0,
              default_output_type='text/html',
              allowable_content_types=('text/plain'),
              ),      
      
              
              
    DataGridField('options',
             searchable = True,
             columns=("option", "price_adjustment"),
             allow_empty_rows = False,
             widget = DataGridWidget(label='Options',
                                     auto_insert = True,
                                     description="""For instance, "Small", "Medium", and "Large", or "Brown", "Black", and "Red".  You may add as many or few options as you like.""",
                                     label_msgid='label_options',
                                     description_msgid='help_options',
                                     i18n_domain='simplecartitem',
                                     columns={'option' : Column("Option", label_msgid='label_column_option'),
                                              'price_adjustment' : Column("Price Adjustment", label_msgid='label_column_priceadjustment'),
                                             },
                                    ),
      ),       
              
                          
              
    ImageField('image',
                default_output_type='image/jpeg',
                allowable_content_types=('image/*',),
                widget=ImageWidget(label='Image',
                                   description='Optionally upload a picture of the item',
                                   macro_view='flex_image',
                                   label_msgid='label_image',
                                   description_msgid='help_image',
                                   i18n_domain='simplecartitem',
                                   ),
              ),
    BooleanField('instock',
                index='FieldIndex:schema',
                default=1,
                widget=BooleanWidget(label='Is this item in stock?',
                                     description="""If it's not in stock, shoppers can see all the information about it, but can't actually add it to their cart.""",
                                     label_msgid='label_instock',
                                     description_msgid='help_instock',
                                     i18n_domain='simplecartitem',
                                     ),
                ),
    ),
    marshall=RFC822Marshaller(),
    )

class SimpleCartItem(ATCTContent):
    """Simple Cart Item
    """
    meta_type =  'SimpleCartItem'
    portal_type = archetype_name = 'Cart Item'
    immediate_view = 'simplecartitem_view'
    default_view   = 'simplecartitem_view'
    content_icon   = "cart1_icon.gif"
    schema         = schema
    
    # Make sure we get title-to-id generation when an object is created
    _at_rename_after_creation = True
    
        
registerType(SimpleCartItem, PROJECTNAME)
