# Utility methods

from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.i18nl10n import utranslate
from Products.CMFPlone.utils import base_hasattr

def sci_addPortalMessage(message, context, type='info', request=None, translate=True, **kwargs):
    """ This method should be directly used from scripts in skins directory
        Example:
           msg = sci_addPortalMessage('Please enter a number', context)
           return response.redirect('%s/cart?%s' % (context.absolute_url(), msg))
        Parameter message will be taken as msgid and default value for translation.
        If you want to override this behaviour, use kw arguments described below.
        
        sci_addPortalMessage can get another parameters for translation:
           translate (bool) - set to False if message should not be translated
           kwargs  - msgid, default, domain, mapping

    """
    putils = getToolByName(context, 'plone_utils')
    if translate:
        msgid = kwargs.get('msgid', message)
        default = kwargs.get('default', message)
        domain = kwargs.get('domain', 'simplecartitem')
        mapping = kwargs.get('mapping', {})
        message = utranslate(msgid=msgid, default=default, domain=domain, mapping=mapping, context=context)
        
    if base_hasattr(putils, 'addPortalMessage'):
        # use Plone 2.5+ statusmessages. It handles unicode correctly
        putils.addPortalMessage(message, type, request)
        return ''
    else:
        # No statusmessages. It is not possible to pass unicode to URL so
        # convert it to site encoding first.
        if isinstance(message, unicode):
            # do not pass unicode to URL (portal_status_message)
            message = message.encode(putils.getSiteEncoding())
        return 'portal_status_message=%s' % message
    
    